==> evolution-0.10.tar.gz: evolution-0.10/addressbook/gui/component/select-names/e-select-names-text-model.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Authors:
 *   Chris Lahey    <clahey@ximian.com>
 *   Jon Trowbridge <trow@ximian.com>
 *
 * Copyright (C) 2000, 2001 Ximian, Inc.
 */

#ifndef __E_SELECT_NAMES_TEXT_MODEL_H__
#define __E_SELECT_NAMES_TEXT_MODEL_H__

#include <time.h>
#include <gtk/gtk.h>
#include <stdio.h>
#include "e-select-names-model.h"
#include <gal/e-text/e-text-model.h>

#define E_TYPE_SELECT_NAMES_TEXT_MODEL            (e_select_names_text_model_get_type ())
#define E_SELECT_NAMES_TEXT_MODEL(obj)            (GTK_CHECK_CAST ((obj), E_TYPE_SELECT_NAMES_TEXT_MODEL, ESelectNamesTextModel))
#define E_SELECT_NAMES_TEXT_MODEL_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), E_TYPE_SELECT_NAMES_TEXT_MODEL, ESelectNamesTextModelClass))
#define E_IS_SELECT_NAMES_TEXT_MODEL(obj)         (GTK_CHECK_TYPE ((obj), E_TYPE_SELECT_NAMES_TEXT_MODEL))
#define E_IS_SELECT_NAMES_TEXT_MODEL_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), E_TYPE_SELECT_NAMES_TEXT_MODEL))

typedef struct _ESelectNamesTextModel ESelectNamesTextModel;
typedef struct _ESelectNamesTextModelClass ESelectNamesTextModelClass;

struct _ESelectNamesTextModel {
	ETextModel parent;

	ESelectNamesModel *source;
	gint source_changed_id;
	gint source_resize_id;
};

struct _ESelectNamesTextModelClass {
	ETextModelClass parent_class;
};

ETextModel *e_select_names_text_model_new  (ESelectNamesModel *source);

/* Standard Gtk function */			      
GtkType     e_select_names_text_model_get_type (void);

#endif /* ! __E_SELECT_NAMES_TEXT_MODEL_H__ */

==> evolution-0.12.tar.gz: evolution-0.12/addressbook/gui/component/select-names/e-select-names-text-model.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Authors:
 *   Chris Lahey    <clahey@ximian.com>
 *   Jon Trowbridge <trow@ximian.com>
 *
 * Copyright (C) 2000, 2001 Ximian, Inc.
 */

#ifndef __E_SELECT_NAMES_TEXT_MODEL_H__
#define __E_SELECT_NAMES_TEXT_MODEL_H__

#include <time.h>
#include <stdio.h>
#include <gtk/gtkobject.h>
#include <gal/e-text/e-text-model.h>
#include "e-select-names-model.h"

#define E_TYPE_SELECT_NAMES_TEXT_MODEL            (e_select_names_text_model_get_type ())
#define E_SELECT_NAMES_TEXT_MODEL(obj)            (GTK_CHECK_CAST ((obj), E_TYPE_SELECT_NAMES_TEXT_MODEL, ESelectNamesTextModel))
#define E_SELECT_NAMES_TEXT_MODEL_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), E_TYPE_SELECT_NAMES_TEXT_MODEL, ESelectNamesTextModelClass))
#define E_IS_SELECT_NAMES_TEXT_MODEL(obj)         (GTK_CHECK_TYPE ((obj), E_TYPE_SELECT_NAMES_TEXT_MODEL))
#define E_IS_SELECT_NAMES_TEXT_MODEL_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), E_TYPE_SELECT_NAMES_TEXT_MODEL))

typedef struct _ESelectNamesTextModel ESelectNamesTextModel;
typedef struct _ESelectNamesTextModelClass ESelectNamesTextModelClass;

struct _ESelectNamesTextModel {
	ETextModel parent;

	ESelectNamesModel *source;
	gint source_changed_id;
	gint source_resize_id;
};

struct _ESelectNamesTextModelClass {
	ETextModelClass parent_class;
};

ETextModel *e_select_names_text_model_new  (ESelectNamesModel *source);

/* Standard Gtk function */			      
GtkType     e_select_names_text_model_get_type (void);

#endif /* ! __E_SELECT_NAMES_TEXT_MODEL_H__ */
